@@ -737,16 +737,15 @@ where
     where
         T: Float + UncheckedPrimitiveFloat,
     {
-        if size_of::<T>() == 4 {
-            let int = if size_of::<T>() < USIZE_SIZE {
-                self.read_fit_usize::<u32>(position, 32, end)
-            } else {
-                self.read_no_fit_usize::<u32>(position, 32, end)
-            };
-            T::from_f32_unchecked(f32::from_bits(int))
+        if position & 7 == 0 {
+            let byte_pos = position / 8;
+            let bytes = self.slice[byte_pos..byte_pos + size_of::<T>()]
+                .try_into()
+                .unwrap();
+            T::from_bytes::<E>(bytes)
         } else {
-            let int = self.read_no_fit_usize::<u64>(position, 64, end);
-            T::from_f64_unchecked(f64::from_bits(int))
+            let int = self.read_int_unchecked(position, size_of::<T>() * 8, end);
+            T::from_int(int)
         }
     }
 
